@@ -1,6 +1,21 @@
+import base64
 from datetime import datetime
-
+from cryptography.hazmat.primitives.asymmetric.ec import ECDSA
 from django.db.models import Model, CharField, UUIDField, DateTimeField, ForeignKey, PROTECT, TextField
+from cryptography.hazmat.primitives.serialization.base import load_pem_public_key
+from cryptography.hazmat._types import _PUBLIC_KEY_TYPES
+from cryptography.hazmat.primitives import hashes
+from . import settings as dreiattest_settings
+
+from cryptography.hazmat.primitives.asymmetric import (
+    dsa,
+    ec,
+    ed25519,
+    ed448,
+    rsa,
+)
+from pyattest.configs.apple import AppleConfig
+from pyattest.verifiers.apple import AppleVerifier
 
 
 class DeviceSession(Model):
@@ -13,7 +28,8 @@ class DeviceSession(Model):
         index_together = ['user_id', 'session_id']
 
     def __str__(self):
-        return f'{self.user_id};{self.session_id}'
+        session_id = str(self.session_id).upper()
+        return f'{self.user_id};{session_id.lower()}'
 
 
 class Nonce(Model):
@@ -32,5 +48,9 @@ class Key(Model):
     device_session = ForeignKey(DeviceSession, on_delete=PROTECT)
     public_key_id = CharField(max_length=255)
     public_key = TextField()
+    driver = CharField(max_length=255)
     created_at = DateTimeField(auto_now_add=True)
     updated_at = DateTimeField(auto_now=True)
+
+    def load_pem(self) -> _PUBLIC_KEY_TYPES:
+        return load_pem_public_key(self.public_key.encode())
